#[non_exhaustive]pub enum Error {
Show 23 variants
SerdeJsonError(Error),
InvalidUrl(UrlParseError),
InvalidUtf8InBody(Utf8Error),
RustlsCreateConnection(Error),
NativeTlsCreateConnection(Error),
IoError(Error),
MalformedChunkLength,
MalformedChunkEnd,
MalformedContentLength,
HeadersOverflow,
StatusLineOverflow,
AddressNotFound,
RedirectLocationMissing,
InfiniteRedirectionLoop,
TooManyRedirections,
InvalidUtf8InResponse,
HttpsFeatureNotEnabled,
BadProxy,
BadProxyCreds,
ProxyConnect,
InvalidProxyCreds,
BodyOverflow,
Other(&'static str),
}Expand description
Represents an error while sending, receiving, or parsing an HTTP response.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
SerdeJsonError(Error)
Ran into a Serde error.
InvalidUrl(UrlParseError)
The given URL is invalid and we failed parsing.
InvalidUtf8InBody(Utf8Error)
The response body contains invalid UTF-8, so the as_str()
conversion failed.
RustlsCreateConnection(Error)
Ran into a rustls error while creating the connection.
NativeTlsCreateConnection(Error)
Ran into a native-tls error while creating the connection.
IoError(Error)
Ran into an IO problem while loading the response.
MalformedChunkLength
Couldn’t parse the incoming chunk’s length while receiving a
response with the header Transfer-Encoding: chunked.
MalformedChunkEnd
The chunk did not end after reading the previously read amount of bytes.
MalformedContentLength
Couldn’t parse the Content-Length header’s value as an
usize.
HeadersOverflow
The response contains headers whose total size surpasses Request::with_max_headers_size.
StatusLineOverflow
The response’s status line length surpasses Request::with_max_status_line_size.
AddressNotFound
ToSocketAddrs did not resolve to an address.
RedirectLocationMissing
The response was a redirection, but the Location header is
missing.
InfiniteRedirectionLoop
The response redirections caused an infinite redirection loop.
TooManyRedirections
Followed
max_redirections
redirections, won’t follow any more.
InvalidUtf8InResponse
The response contained invalid UTF-8 where it should be valid (eg. headers), so the response cannot interpreted correctly.
HttpsFeatureNotEnabled
Tried to send a secure request (ie. the url started with
https://), but the crate’s https feature was not enabled,
and as such, a connection cannot be made.
BadProxy
The provided proxy information was not properly formatted. See Proxy methods for the valid format.
BadProxyCreds
The provided credentials were rejected by the proxy server.
ProxyConnect
The provided proxy credentials were malformed.
InvalidProxyCreds
The provided credentials were rejected by the proxy server.
BodyOverflow
The response body size surpasses Request::with_max_body_size.
Other(&'static str)
This is a special error case, one that should never be
returned! Think of this as a cleaner alternative to calling
unreachable!() inside the library. If you come across this,
please open an issue, and include the string inside this
error, as it can be used to locate the problem.